#
#   Add missing test for .tar.Z suffix to fix Simon George's problem
#
import os,string
from unix_base import *

def downloadroot(file):
	if   tail(file,'tar.gz'):
		root = ztar_root(file)
	elif tail(file,'.tgz'):
		root = ztar_root(file)
	elif tail(file,'.tar'):
		root = tar_root(file)
	elif tail(file,'.tar.Z'):
		root = tar_root(file)
	else:
		root = ''
	if not root=='' and verbose:
		print 'Tarball ['+file+'] has root directory ['+root+'].'
	return root

def ztar_root(file):
#	lines = os.popen('tar -z -t -f '+file).readlines()
	lines = os.popen('gunzip --stdout '+file+' | tar -t -f -').readlines()

	if len(lines)>0: 
		index = string.find(lines[0],'/')
		if index==-1:
			line = lines[0]
			return line[:-1]
		else:
			line = lines[0][:index]
			return line
	else:            
		return ''

def tar_root(file):
	lines = os.popen('tar -t -f '+file).readlines()
#
#	if len(lines)>0: return lines[0][:-1]
#	else:            return ''
#			
	if len(lines)>0: 
		index = string.find(lines[0],'/')
		if index==-1:
			line = lines[0]
			return line[:-1]
		else:
			line = lines[0][:index]
			return line
	else:            
		return ''
	
